mirror of
https://github.com/NVIDIA/cuda-samples.git
synced 2026-10-11 23:38:25 +08:00
Add and Update samples for CUDA 10.0
This commit is contained in:
300
Samples/p2pBandwidthLatencyTest/Makefile
Normal file
300
Samples/p2pBandwidthLatencyTest/Makefile
Normal file
@@ -0,0 +1,300 @@
|
||||
################################################################################
|
||||
# Copyright (c) 2018, NVIDIA CORPORATION. All rights reserved.
|
||||
#
|
||||
# Redistribution and use in source and binary forms, with or without
|
||||
# modification, are permitted provided that the following conditions
|
||||
# are met:
|
||||
# * Redistributions of source code must retain the above copyright
|
||||
# notice, this list of conditions and the following disclaimer.
|
||||
# * Redistributions in binary form must reproduce the above copyright
|
||||
# notice, this list of conditions and the following disclaimer in the
|
||||
# documentation and/or other materials provided with the distribution.
|
||||
# * Neither the name of NVIDIA CORPORATION nor the names of its
|
||||
# contributors may be used to endorse or promote products derived
|
||||
# from this software without specific prior written permission.
|
||||
#
|
||||
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ``AS IS'' AND ANY
|
||||
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
|
||||
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
|
||||
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
|
||||
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
|
||||
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
|
||||
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
|
||||
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
|
||||
# OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
|
||||
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
|
||||
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
|
||||
#
|
||||
################################################################################
|
||||
#
|
||||
# Makefile project only supported on Mac OS X and Linux Platforms)
|
||||
#
|
||||
################################################################################
|
||||
|
||||
# Location of the CUDA Toolkit
|
||||
CUDA_PATH ?= /usr/local/cuda
|
||||
|
||||
##############################
|
||||
# start deprecated interface #
|
||||
##############################
|
||||
ifeq ($(x86_64),1)
|
||||
$(info WARNING - x86_64 variable has been deprecated)
|
||||
$(info WARNING - please use TARGET_ARCH=x86_64 instead)
|
||||
TARGET_ARCH ?= x86_64
|
||||
endif
|
||||
ifeq ($(ARMv7),1)
|
||||
$(info WARNING - ARMv7 variable has been deprecated)
|
||||
$(info WARNING - please use TARGET_ARCH=armv7l instead)
|
||||
TARGET_ARCH ?= armv7l
|
||||
endif
|
||||
ifeq ($(aarch64),1)
|
||||
$(info WARNING - aarch64 variable has been deprecated)
|
||||
$(info WARNING - please use TARGET_ARCH=aarch64 instead)
|
||||
TARGET_ARCH ?= aarch64
|
||||
endif
|
||||
ifeq ($(ppc64le),1)
|
||||
$(info WARNING - ppc64le variable has been deprecated)
|
||||
$(info WARNING - please use TARGET_ARCH=ppc64le instead)
|
||||
TARGET_ARCH ?= ppc64le
|
||||
endif
|
||||
ifneq ($(GCC),)
|
||||
$(info WARNING - GCC variable has been deprecated)
|
||||
$(info WARNING - please use HOST_COMPILER=$(GCC) instead)
|
||||
HOST_COMPILER ?= $(GCC)
|
||||
endif
|
||||
ifneq ($(abi),)
|
||||
$(error ERROR - abi variable has been removed)
|
||||
endif
|
||||
############################
|
||||
# end deprecated interface #
|
||||
############################
|
||||
|
||||
# architecture
|
||||
HOST_ARCH := $(shell uname -m)
|
||||
TARGET_ARCH ?= $(HOST_ARCH)
|
||||
ifneq (,$(filter $(TARGET_ARCH),x86_64 aarch64 ppc64le armv7l))
|
||||
ifneq ($(TARGET_ARCH),$(HOST_ARCH))
|
||||
ifneq (,$(filter $(TARGET_ARCH),x86_64 aarch64 ppc64le))
|
||||
TARGET_SIZE := 64
|
||||
else ifneq (,$(filter $(TARGET_ARCH),armv7l))
|
||||
TARGET_SIZE := 32
|
||||
endif
|
||||
else
|
||||
TARGET_SIZE := $(shell getconf LONG_BIT)
|
||||
endif
|
||||
else
|
||||
$(error ERROR - unsupported value $(TARGET_ARCH) for TARGET_ARCH!)
|
||||
endif
|
||||
ifneq ($(TARGET_ARCH),$(HOST_ARCH))
|
||||
ifeq (,$(filter $(HOST_ARCH)-$(TARGET_ARCH),aarch64-armv7l x86_64-armv7l x86_64-aarch64 x86_64-ppc64le))
|
||||
$(error ERROR - cross compiling from $(HOST_ARCH) to $(TARGET_ARCH) is not supported!)
|
||||
endif
|
||||
endif
|
||||
|
||||
# When on native aarch64 system with userspace of 32-bit, change TARGET_ARCH to armv7l
|
||||
ifeq ($(HOST_ARCH)-$(TARGET_ARCH)-$(TARGET_SIZE),aarch64-aarch64-32)
|
||||
TARGET_ARCH = armv7l
|
||||
endif
|
||||
|
||||
# operating system
|
||||
HOST_OS := $(shell uname -s 2>/dev/null | tr "[:upper:]" "[:lower:]")
|
||||
TARGET_OS ?= $(HOST_OS)
|
||||
ifeq (,$(filter $(TARGET_OS),linux darwin qnx android))
|
||||
$(error ERROR - unsupported value $(TARGET_OS) for TARGET_OS!)
|
||||
endif
|
||||
|
||||
# host compiler
|
||||
ifeq ($(TARGET_OS),darwin)
|
||||
ifeq ($(shell expr `xcodebuild -version | grep -i xcode | awk '{print $$2}' | cut -d'.' -f1` \>= 5),1)
|
||||
HOST_COMPILER ?= clang++
|
||||
endif
|
||||
else ifneq ($(TARGET_ARCH),$(HOST_ARCH))
|
||||
ifeq ($(HOST_ARCH)-$(TARGET_ARCH),x86_64-armv7l)
|
||||
ifeq ($(TARGET_OS),linux)
|
||||
HOST_COMPILER ?= arm-linux-gnueabihf-g++
|
||||
else ifeq ($(TARGET_OS),qnx)
|
||||
ifeq ($(QNX_HOST),)
|
||||
$(error ERROR - QNX_HOST must be passed to the QNX host toolchain)
|
||||
endif
|
||||
ifeq ($(QNX_TARGET),)
|
||||
$(error ERROR - QNX_TARGET must be passed to the QNX target toolchain)
|
||||
endif
|
||||
export QNX_HOST
|
||||
export QNX_TARGET
|
||||
HOST_COMPILER ?= $(QNX_HOST)/usr/bin/arm-unknown-nto-qnx6.6.0eabi-g++
|
||||
else ifeq ($(TARGET_OS),android)
|
||||
HOST_COMPILER ?= arm-linux-androideabi-g++
|
||||
endif
|
||||
else ifeq ($(TARGET_ARCH),aarch64)
|
||||
ifeq ($(TARGET_OS), linux)
|
||||
HOST_COMPILER ?= aarch64-linux-gnu-g++
|
||||
else ifeq ($(TARGET_OS),qnx)
|
||||
ifeq ($(QNX_HOST),)
|
||||
$(error ERROR - QNX_HOST must be passed to the QNX host toolchain)
|
||||
endif
|
||||
ifeq ($(QNX_TARGET),)
|
||||
$(error ERROR - QNX_TARGET must be passed to the QNX target toolchain)
|
||||
endif
|
||||
export QNX_HOST
|
||||
export QNX_TARGET
|
||||
HOST_COMPILER ?= $(QNX_HOST)/usr/bin/aarch64-unknown-nto-qnx7.0.0-g++
|
||||
else ifeq ($(TARGET_OS), android)
|
||||
HOST_COMPILER ?= aarch64-linux-android-clang++
|
||||
endif
|
||||
else ifeq ($(TARGET_ARCH),ppc64le)
|
||||
HOST_COMPILER ?= powerpc64le-linux-gnu-g++
|
||||
endif
|
||||
endif
|
||||
HOST_COMPILER ?= g++
|
||||
NVCC := $(CUDA_PATH)/bin/nvcc -ccbin $(HOST_COMPILER)
|
||||
|
||||
# internal flags
|
||||
NVCCFLAGS := -m${TARGET_SIZE}
|
||||
CCFLAGS :=
|
||||
LDFLAGS :=
|
||||
|
||||
# build flags
|
||||
ifeq ($(TARGET_OS),darwin)
|
||||
LDFLAGS += -rpath $(CUDA_PATH)/lib
|
||||
CCFLAGS += -arch $(HOST_ARCH)
|
||||
else ifeq ($(HOST_ARCH)-$(TARGET_ARCH)-$(TARGET_OS),x86_64-armv7l-linux)
|
||||
LDFLAGS += --dynamic-linker=/lib/ld-linux-armhf.so.3
|
||||
CCFLAGS += -mfloat-abi=hard
|
||||
else ifeq ($(TARGET_OS),android)
|
||||
LDFLAGS += -pie
|
||||
CCFLAGS += -fpie -fpic -fexceptions
|
||||
endif
|
||||
|
||||
ifneq ($(TARGET_ARCH),$(HOST_ARCH))
|
||||
ifeq ($(TARGET_ARCH)-$(TARGET_OS),armv7l-linux)
|
||||
ifneq ($(TARGET_FS),)
|
||||
GCCVERSIONLTEQ46 := $(shell expr `$(HOST_COMPILER) -dumpversion` \<= 4.6)
|
||||
ifeq ($(GCCVERSIONLTEQ46),1)
|
||||
CCFLAGS += --sysroot=$(TARGET_FS)
|
||||
endif
|
||||
LDFLAGS += --sysroot=$(TARGET_FS)
|
||||
LDFLAGS += -rpath-link=$(TARGET_FS)/lib
|
||||
LDFLAGS += -rpath-link=$(TARGET_FS)/usr/lib
|
||||
LDFLAGS += -rpath-link=$(TARGET_FS)/usr/lib/arm-linux-gnueabihf
|
||||
endif
|
||||
endif
|
||||
ifeq ($(TARGET_ARCH)-$(TARGET_OS),aarch64-linux)
|
||||
ifneq ($(TARGET_FS),)
|
||||
GCCVERSIONLTEQ46 := $(shell expr `$(HOST_COMPILER) -dumpversion` \<= 4.6)
|
||||
ifeq ($(GCCVERSIONLTEQ46),1)
|
||||
CCFLAGS += --sysroot=$(TARGET_FS)
|
||||
endif
|
||||
LDFLAGS += --sysroot=$(TARGET_FS)
|
||||
LDFLAGS += -rpath-link=$(TARGET_FS)/lib -L $(TARGET_FS)/lib
|
||||
LDFLAGS += -rpath-link=$(TARGET_FS)/usr/lib -L $(TARGET_FS)/usr/lib
|
||||
LDFLAGS += -rpath-link=$(TARGET_FS)/usr/lib/aarch64-linux-gnu -L $(TARGET_FS)/usr/lib/aarch64-linux-gnu
|
||||
LDFLAGS += --unresolved-symbols=ignore-in-shared-libs
|
||||
CCFLAGS += -isystem=$(TARGET_FS)/usr/include
|
||||
CCFLAGS += -isystem=$(TARGET_FS)/usr/include/aarch64-linux-gnu
|
||||
endif
|
||||
endif
|
||||
endif
|
||||
|
||||
ifeq ($(TARGET_OS),qnx)
|
||||
CCFLAGS += -DWIN_INTERFACE_CUSTOM
|
||||
LDFLAGS += -lsocket
|
||||
endif
|
||||
|
||||
# Install directory of different arch
|
||||
CUDA_INSTALL_TARGET_DIR :=
|
||||
ifeq ($(TARGET_ARCH)-$(TARGET_OS),armv7l-linux)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/armv7-linux-gnueabihf/
|
||||
else ifeq ($(TARGET_ARCH)-$(TARGET_OS),aarch64-linux)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/aarch64-linux/
|
||||
else ifeq ($(TARGET_ARCH)-$(TARGET_OS),armv7l-android)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/armv7-linux-androideabi/
|
||||
else ifeq ($(TARGET_ARCH)-$(TARGET_OS),aarch64-android)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/aarch64-linux-androideabi/
|
||||
else ifeq ($(TARGET_ARCH)-$(TARGET_OS),armv7l-qnx)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/ARMv7-linux-QNX/
|
||||
else ifeq ($(TARGET_ARCH)-$(TARGET_OS),aarch64-qnx)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/aarch64-qnx/
|
||||
else ifeq ($(TARGET_ARCH),ppc64le)
|
||||
CUDA_INSTALL_TARGET_DIR = targets/ppc64le-linux/
|
||||
endif
|
||||
|
||||
# Debug build flags
|
||||
ifeq ($(dbg),1)
|
||||
NVCCFLAGS += -g -G
|
||||
BUILD_TYPE := debug
|
||||
else
|
||||
BUILD_TYPE := release
|
||||
endif
|
||||
|
||||
ALL_CCFLAGS :=
|
||||
ALL_CCFLAGS += $(NVCCFLAGS)
|
||||
ALL_CCFLAGS += $(EXTRA_NVCCFLAGS)
|
||||
ALL_CCFLAGS += $(addprefix -Xcompiler ,$(CCFLAGS))
|
||||
ALL_CCFLAGS += $(addprefix -Xcompiler ,$(EXTRA_CCFLAGS))
|
||||
|
||||
SAMPLE_ENABLED := 1
|
||||
|
||||
ALL_LDFLAGS :=
|
||||
ALL_LDFLAGS += $(ALL_CCFLAGS)
|
||||
ALL_LDFLAGS += $(addprefix -Xlinker ,$(LDFLAGS))
|
||||
ALL_LDFLAGS += $(addprefix -Xlinker ,$(EXTRA_LDFLAGS))
|
||||
|
||||
# Common includes and paths for CUDA
|
||||
INCLUDES := -I../../Common
|
||||
LIBRARIES :=
|
||||
|
||||
################################################################################
|
||||
|
||||
# Gencode arguments
|
||||
SMS ?= 30 35 37 50 52 60 61 70 75
|
||||
|
||||
ifeq ($(SMS),)
|
||||
$(info >>> WARNING - no SM architectures have been specified - waiving sample <<<)
|
||||
SAMPLE_ENABLED := 0
|
||||
endif
|
||||
|
||||
ifeq ($(GENCODE_FLAGS),)
|
||||
# Generate SASS code for each SM architecture listed in $(SMS)
|
||||
$(foreach sm,$(SMS),$(eval GENCODE_FLAGS += -gencode arch=compute_$(sm),code=sm_$(sm)))
|
||||
|
||||
# Generate PTX code from the highest SM architecture in $(SMS) to guarantee forward-compatibility
|
||||
HIGHEST_SM := $(lastword $(sort $(SMS)))
|
||||
ifneq ($(HIGHEST_SM),)
|
||||
GENCODE_FLAGS += -gencode arch=compute_$(HIGHEST_SM),code=compute_$(HIGHEST_SM)
|
||||
endif
|
||||
endif
|
||||
|
||||
ifeq ($(SAMPLE_ENABLED),0)
|
||||
EXEC ?= @echo "[@]"
|
||||
endif
|
||||
|
||||
################################################################################
|
||||
|
||||
# Target rules
|
||||
all: build
|
||||
|
||||
build: p2pBandwidthLatencyTest
|
||||
|
||||
check.deps:
|
||||
ifeq ($(SAMPLE_ENABLED),0)
|
||||
@echo "Sample will be waived due to the above missing dependencies"
|
||||
else
|
||||
@echo "Sample is ready - all dependencies have been met"
|
||||
endif
|
||||
|
||||
p2pBandwidthLatencyTest.o:p2pBandwidthLatencyTest.cu
|
||||
$(EXEC) $(NVCC) $(INCLUDES) $(ALL_CCFLAGS) $(GENCODE_FLAGS) -o $@ -c $<
|
||||
|
||||
p2pBandwidthLatencyTest: p2pBandwidthLatencyTest.o
|
||||
$(EXEC) $(NVCC) $(ALL_LDFLAGS) $(GENCODE_FLAGS) -o $@ $+ $(LIBRARIES)
|
||||
$(EXEC) mkdir -p ../../bin/$(TARGET_ARCH)/$(TARGET_OS)/$(BUILD_TYPE)
|
||||
$(EXEC) cp $@ ../../bin/$(TARGET_ARCH)/$(TARGET_OS)/$(BUILD_TYPE)
|
||||
|
||||
run: build
|
||||
$(EXEC) ./p2pBandwidthLatencyTest
|
||||
|
||||
clean:
|
||||
rm -f p2pBandwidthLatencyTest p2pBandwidthLatencyTest.o
|
||||
rm -rf ../../bin/$(TARGET_ARCH)/$(TARGET_OS)/$(BUILD_TYPE)/p2pBandwidthLatencyTest
|
||||
|
||||
clobber: clean
|
||||
77
Samples/p2pBandwidthLatencyTest/NsightEclipse.xml
Normal file
77
Samples/p2pBandwidthLatencyTest/NsightEclipse.xml
Normal file
@@ -0,0 +1,77 @@
|
||||
<?xml version="1.0" encoding="UTF-8"?>
|
||||
<!DOCTYPE entry SYSTEM "SamplesInfo.dtd">
|
||||
<entry>
|
||||
<name>p2pBandwidthLatencyTest</name>
|
||||
<cuda_api_list>
|
||||
<toolkit>cudaDeviceCanAccessPeer</toolkit>
|
||||
<toolkit>cudaDeviceEnablePeerAccess</toolkit>
|
||||
<toolkit>cudaDeviceDisablePeerAccess</toolkit>
|
||||
<toolkit>cudaEventCreateWithFlags</toolkit>
|
||||
<toolkit>cudaEventElapsedTime</toolkit>
|
||||
<toolkit>cudaMemcpy</toolkit>
|
||||
</cuda_api_list>
|
||||
<description><![CDATA[This application demonstrates the CUDA Peer-To-Peer (P2P) data transfers between pairs of GPUs and computes latency and bandwidth. Tests on GPU pairs using P2P and without P2P are tested.]]></description>
|
||||
<devicecompilation>whole</devicecompilation>
|
||||
<includepaths>
|
||||
<path>./</path>
|
||||
<path>../</path>
|
||||
<path>../../common/inc</path>
|
||||
</includepaths>
|
||||
<keyconcepts>
|
||||
<concept level="basic">Performance Strategies</concept>
|
||||
<concept level="basic">Asynchronous Data Transfers</concept>
|
||||
<concept level="basic">Unified Virtual Address Space</concept>
|
||||
<concept level="basic">Peer to Peer Data Transfers</concept>
|
||||
<concept level="basic">Multi-GPU</concept>
|
||||
</keyconcepts>
|
||||
<keywords>
|
||||
<keyword>CUDA</keyword>
|
||||
<keyword>Performance</keyword>
|
||||
<keyword>multi-GPU support</keyword>
|
||||
<keyword>peer to peer</keyword>
|
||||
</keywords>
|
||||
<libraries>
|
||||
</libraries>
|
||||
<librarypaths>
|
||||
</librarypaths>
|
||||
<nsight_eclipse>true</nsight_eclipse>
|
||||
<primary_file>p2pBandwidthLatencyTest.cu</primary_file>
|
||||
<scopes>
|
||||
<scope>1:CUDA Basic Topics</scope>
|
||||
<scope>1:Performance Strategies</scope>
|
||||
</scopes>
|
||||
<sm-arch>sm30</sm-arch>
|
||||
<sm-arch>sm35</sm-arch>
|
||||
<sm-arch>sm37</sm-arch>
|
||||
<sm-arch>sm50</sm-arch>
|
||||
<sm-arch>sm52</sm-arch>
|
||||
<sm-arch>sm60</sm-arch>
|
||||
<sm-arch>sm61</sm-arch>
|
||||
<sm-arch>sm70</sm-arch>
|
||||
<sm-arch>sm75</sm-arch>
|
||||
<supported_envs>
|
||||
<env>
|
||||
<arch>x86_64</arch>
|
||||
<platform>linux</platform>
|
||||
</env>
|
||||
<env>
|
||||
<platform>windows7</platform>
|
||||
</env>
|
||||
<env>
|
||||
<arch>x86_64</arch>
|
||||
<platform>macosx</platform>
|
||||
</env>
|
||||
<env>
|
||||
<arch>arm</arch>
|
||||
</env>
|
||||
<env>
|
||||
<arch>ppc64le</arch>
|
||||
<platform>linux</platform>
|
||||
</env>
|
||||
</supported_envs>
|
||||
<supported_sm_architectures>
|
||||
<include>all</include>
|
||||
</supported_sm_architectures>
|
||||
<title>Peer-to-Peer Bandwidth Latency Test with Multi-GPUs</title>
|
||||
<type>exe</type>
|
||||
</entry>
|
||||
94
Samples/p2pBandwidthLatencyTest/README.md
Normal file
94
Samples/p2pBandwidthLatencyTest/README.md
Normal file
@@ -0,0 +1,94 @@
|
||||
# p2pBandwidthLatencyTest - Peer-to-Peer Bandwidth Latency Test with Multi-GPUs
|
||||
|
||||
## Description
|
||||
|
||||
This application demonstrates the CUDA Peer-To-Peer (P2P) data transfers between pairs of GPUs and computes latency and bandwidth. Tests on GPU pairs using P2P and without P2P are tested.
|
||||
|
||||
## Key Concepts
|
||||
|
||||
Performance Strategies, Asynchronous Data Transfers, Unified Virtual Address Space, Peer to Peer Data Transfers, Multi-GPU
|
||||
|
||||
## Supported SM Architectures
|
||||
|
||||
[SM 3.0 ](https://developer.nvidia.com/cuda-gpus) [SM 3.5 ](https://developer.nvidia.com/cuda-gpus) [SM 3.7 ](https://developer.nvidia.com/cuda-gpus) [SM 5.0 ](https://developer.nvidia.com/cuda-gpus) [SM 5.2 ](https://developer.nvidia.com/cuda-gpus) [SM 6.0 ](https://developer.nvidia.com/cuda-gpus) [SM 6.1 ](https://developer.nvidia.com/cuda-gpus) [SM 7.0 ](https://developer.nvidia.com/cuda-gpus) [SM 7.5 ](https://developer.nvidia.com/cuda-gpus)
|
||||
|
||||
## Supported OSes
|
||||
|
||||
Linux, Windows, MacOSX
|
||||
|
||||
## Supported CPU Architecture
|
||||
|
||||
x86_64, ppc64le, armv7l
|
||||
|
||||
## CUDA APIs involved
|
||||
|
||||
### [CUDA Runtime API](http://docs.nvidia.com/cuda/cuda-runtime-api/index.html)
|
||||
cudaDeviceCanAccessPeer, cudaDeviceEnablePeerAccess, cudaDeviceDisablePeerAccess, cudaEventCreateWithFlags, cudaEventElapsedTime, cudaMemcpy
|
||||
|
||||
## Prerequisites
|
||||
|
||||
Download and install the [CUDA Toolkit 10.0](https://developer.nvidia.com/cuda-downloads) for your corresponding platform.
|
||||
|
||||
## Build and Run
|
||||
|
||||
### Windows
|
||||
The Windows samples are built using the Visual Studio IDE. Solution files (.sln) are provided for each supported version of Visual Studio, using the format:
|
||||
```
|
||||
*_vs<version>.sln - for Visual Studio <version>
|
||||
```
|
||||
Each individual sample has its own set of solution files in its directory:
|
||||
|
||||
To build/examine all the samples at once, the complete solution files should be used. To build/examine a single sample, the individual sample solution files should be used.
|
||||
> **Note:** Some samples require that the Microsoft DirectX SDK (June 2010 or newer) be installed and that the VC++ directory paths are properly set up (**Tools > Options...**). Check DirectX Dependencies section for details."
|
||||
|
||||
### Linux
|
||||
The Linux samples are built using makefiles. To use the makefiles, change the current directory to the sample directory you wish to build, and run make:
|
||||
```
|
||||
$ cd <sample_dir>
|
||||
$ make
|
||||
```
|
||||
The samples makefiles can take advantage of certain options:
|
||||
* **TARGET_ARCH=<arch>** - cross-compile targeting a specific architecture. Allowed architectures are x86_64, ppc64le, armv7l.
|
||||
By default, TARGET_ARCH is set to HOST_ARCH. On a x86_64 machine, not setting TARGET_ARCH is the equivalent of setting TARGET_ARCH=x86_64.<br/>
|
||||
`$ make TARGET_ARCH=x86_64` <br/> `$ make TARGET_ARCH=ppc64le` <br/> `$ make TARGET_ARCH=armv7l` <br/>
|
||||
See [here](http://docs.nvidia.com/cuda/cuda-samples/index.html#cross-samples) for more details.
|
||||
* **dbg=1** - build with debug symbols
|
||||
```
|
||||
$ make dbg=1
|
||||
```
|
||||
* **SMS="A B ..."** - override the SM architectures for which the sample will be built, where `"A B ..."` is a space-delimited list of SM architectures. For example, to generate SASS for SM 50 and SM 60, use `SMS="50 60"`.
|
||||
```
|
||||
$ make SMS="50 60"
|
||||
```
|
||||
|
||||
* **HOST_COMPILER=<host_compiler>** - override the default g++ host compiler. See the [Linux Installation Guide](http://docs.nvidia.com/cuda/cuda-installation-guide-linux/index.html#system-requirements) for a list of supported host compilers.
|
||||
```
|
||||
$ make HOST_COMPILER=g++
|
||||
```
|
||||
|
||||
### Mac
|
||||
The Mac samples are built using makefiles. To use the makefiles, change directory into the sample directory you wish to build, and run make:
|
||||
```
|
||||
$ cd <sample_dir>
|
||||
$ make
|
||||
```
|
||||
|
||||
The samples makefiles can take advantage of certain options:
|
||||
|
||||
* **dbg=1** - build with debug symbols
|
||||
```
|
||||
$ make dbg=1
|
||||
```
|
||||
|
||||
* **SMS="A B ..."** - override the SM architectures for which the sample will be built, where "A B ..." is a space-delimited list of SM architectures. For example, to generate SASS for SM 50 and SM 60, use SMS="50 60".
|
||||
```
|
||||
$ make SMS="A B ..."
|
||||
```
|
||||
|
||||
* **HOST_COMPILER=<host_compiler>** - override the default clang host compiler. See the [Mac Installation Guide](http://docs.nvidia.com/cuda/cuda-installation-guide-mac-os-x/index.html#system-requirements) for a list of supported host compilers.
|
||||
```
|
||||
$ make HOST_COMPILER=clang
|
||||
```
|
||||
|
||||
## References (for more details)
|
||||
|
||||
682
Samples/p2pBandwidthLatencyTest/p2pBandwidthLatencyTest.cu
Normal file
682
Samples/p2pBandwidthLatencyTest/p2pBandwidthLatencyTest.cu
Normal file
@@ -0,0 +1,682 @@
|
||||
/* Copyright (c) 2018, NVIDIA CORPORATION. All rights reserved.
|
||||
*
|
||||
* Redistribution and use in source and binary forms, with or without
|
||||
* modification, are permitted provided that the following conditions
|
||||
* are met:
|
||||
* * Redistributions of source code must retain the above copyright
|
||||
* notice, this list of conditions and the following disclaimer.
|
||||
* * Redistributions in binary form must reproduce the above copyright
|
||||
* notice, this list of conditions and the following disclaimer in the
|
||||
* documentation and/or other materials provided with the distribution.
|
||||
* * Neither the name of NVIDIA CORPORATION nor the names of its
|
||||
* contributors may be used to endorse or promote products derived
|
||||
* from this software without specific prior written permission.
|
||||
*
|
||||
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ``AS IS'' AND ANY
|
||||
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
|
||||
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
|
||||
* PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
|
||||
* CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
|
||||
* EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
|
||||
* PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
|
||||
* PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
|
||||
* OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
|
||||
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
|
||||
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
|
||||
*/
|
||||
|
||||
#include <cstdio>
|
||||
#include <vector>
|
||||
|
||||
#include <helper_cuda.h>
|
||||
#include <helper_timer.h>
|
||||
|
||||
using namespace std;
|
||||
|
||||
const char *sSampleName = "P2P (Peer-to-Peer) GPU Bandwidth Latency Test";
|
||||
|
||||
typedef enum {
|
||||
P2P_WRITE = 0,
|
||||
P2P_READ = 1,
|
||||
} P2PDataTransfer;
|
||||
|
||||
typedef enum {
|
||||
CE = 0,
|
||||
SM = 1,
|
||||
} P2PEngine;
|
||||
|
||||
P2PEngine p2p_mechanism = CE; // By default use Copy Engine
|
||||
|
||||
// Macro for checking cuda errors following a cuda launch or api call
|
||||
#define cudaCheckError() \
|
||||
{ \
|
||||
cudaError_t e = cudaGetLastError(); \
|
||||
if (e != cudaSuccess) { \
|
||||
printf("Cuda failure %s:%d: '%s'\n", __FILE__, __LINE__, \
|
||||
cudaGetErrorString(e)); \
|
||||
exit(EXIT_FAILURE); \
|
||||
} \
|
||||
}
|
||||
__global__ void delay(volatile int *flag,
|
||||
unsigned long long timeout_clocks = 10000000) {
|
||||
// Wait until the application notifies us that it has completed queuing up the
|
||||
// experiment, or timeout and exit, allowing the application to make progress
|
||||
long long int start_clock, sample_clock;
|
||||
start_clock = clock64();
|
||||
|
||||
while (!*flag) {
|
||||
sample_clock = clock64();
|
||||
|
||||
if (sample_clock - start_clock > timeout_clocks) {
|
||||
break;
|
||||
}
|
||||
}
|
||||
}
|
||||
|
||||
// This kernel is for demonstration purposes only, not a performant kernel for
|
||||
// p2p transfers.
|
||||
__global__ void copyp2p(int4 *__restrict__ dest, int4 const *__restrict__ src,
|
||||
size_t num_elems) {
|
||||
size_t globalId = blockIdx.x * blockDim.x + threadIdx.x;
|
||||
size_t gridSize = blockDim.x * gridDim.x;
|
||||
|
||||
#pragma unroll(5)
|
||||
for (size_t i = globalId; i < num_elems; i += gridSize) {
|
||||
dest[i] = src[i];
|
||||
}
|
||||
}
|
||||
|
||||
///////////////////////////////////////////////////////////////////////////
|
||||
// Print help screen
|
||||
///////////////////////////////////////////////////////////////////////////
|
||||
void printHelp(void) {
|
||||
printf("Usage: p2pBandwidthLatencyTest [OPTION]...\n");
|
||||
printf("Tests bandwidth/latency of GPU pairs using P2P and without P2P\n");
|
||||
printf("\n");
|
||||
|
||||
printf("Options:\n");
|
||||
printf("--help\t\tDisplay this help menu\n");
|
||||
printf(
|
||||
"--p2p_read\tUse P2P reads for data transfers between GPU pairs and show "
|
||||
"corresponding results.\n \t\tDefault used is P2P write operation.\n");
|
||||
printf("--sm_copy\tUse SM intiated p2p transfers instead of Copy Engine\n");
|
||||
}
|
||||
|
||||
void checkP2Paccess(int numGPUs) {
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
cudaSetDevice(i);
|
||||
cudaCheckError();
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
int access;
|
||||
if (i != j) {
|
||||
cudaDeviceCanAccessPeer(&access, i, j);
|
||||
cudaCheckError();
|
||||
printf("Device=%d %s Access Peer Device=%d\n", i,
|
||||
access ? "CAN" : "CANNOT", j);
|
||||
}
|
||||
}
|
||||
}
|
||||
printf(
|
||||
"\n***NOTE: In case a device doesn't have P2P access to other one, it "
|
||||
"falls back to normal memcopy procedure.\nSo you can see lesser "
|
||||
"Bandwidth (GB/s) and unstable Latency (us) in those cases.\n\n");
|
||||
}
|
||||
|
||||
void performP2PCopy(int *dest, int destDevice, int *src, int srcDevice,
|
||||
int num_elems, int repeat, bool p2paccess,
|
||||
cudaStream_t streamToRun) {
|
||||
int blockSize = 0;
|
||||
int numBlocks = 0;
|
||||
|
||||
cudaOccupancyMaxPotentialBlockSize(&numBlocks, &blockSize, copyp2p);
|
||||
cudaCheckError();
|
||||
|
||||
if (p2p_mechanism == SM && p2paccess) {
|
||||
for (int r = 0; r < repeat; r++) {
|
||||
copyp2p<<<numBlocks, blockSize, 0, streamToRun>>>(
|
||||
(int4 *)dest, (int4 *)src, num_elems / 4);
|
||||
}
|
||||
} else {
|
||||
for (int r = 0; r < repeat; r++) {
|
||||
cudaMemcpyPeerAsync(dest, destDevice, src, srcDevice,
|
||||
sizeof(int) * num_elems, streamToRun);
|
||||
}
|
||||
}
|
||||
}
|
||||
|
||||
void outputBandwidthMatrix(int numGPUs, bool p2p, P2PDataTransfer p2p_method) {
|
||||
int numElems = 10000000;
|
||||
int repeat = 5;
|
||||
volatile int *flag = NULL;
|
||||
vector<int *> buffers(numGPUs);
|
||||
vector<int *> buffersD2D(numGPUs); // buffer for D2D, that is, intra-GPU copy
|
||||
vector<cudaEvent_t> start(numGPUs);
|
||||
vector<cudaEvent_t> stop(numGPUs);
|
||||
vector<cudaStream_t> stream(numGPUs);
|
||||
|
||||
cudaHostAlloc((void **)&flag, sizeof(*flag), cudaHostAllocPortable);
|
||||
cudaCheckError();
|
||||
|
||||
for (int d = 0; d < numGPUs; d++) {
|
||||
cudaSetDevice(d);
|
||||
cudaStreamCreateWithFlags(&stream[d], cudaStreamNonBlocking);
|
||||
cudaMalloc(&buffers[d], numElems * sizeof(int));
|
||||
cudaCheckError();
|
||||
cudaMalloc(&buffersD2D[d], numElems * sizeof(int));
|
||||
cudaCheckError();
|
||||
cudaEventCreate(&start[d]);
|
||||
cudaCheckError();
|
||||
cudaEventCreate(&stop[d]);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
vector<double> bandwidthMatrix(numGPUs * numGPUs);
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
cudaSetDevice(i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
int access = 0;
|
||||
if (p2p) {
|
||||
cudaDeviceCanAccessPeer(&access, i, j);
|
||||
if (access) {
|
||||
cudaDeviceEnablePeerAccess(j, 0);
|
||||
cudaCheckError();
|
||||
cudaSetDevice(j);
|
||||
cudaCheckError();
|
||||
cudaDeviceEnablePeerAccess(i, 0);
|
||||
cudaCheckError();
|
||||
cudaSetDevice(i);
|
||||
cudaCheckError();
|
||||
}
|
||||
}
|
||||
|
||||
cudaStreamSynchronize(stream[i]);
|
||||
cudaCheckError();
|
||||
|
||||
// Block the stream until all the work is queued up
|
||||
// DANGER! - cudaMemcpy*Async may infinitely block waiting for
|
||||
// room to push the operation, so keep the number of repeatitions
|
||||
// relatively low. Higher repeatitions will cause the delay kernel
|
||||
// to timeout and lead to unstable results.
|
||||
*flag = 0;
|
||||
delay<<<1, 1, 0, stream[i]>>>(flag);
|
||||
cudaCheckError();
|
||||
cudaEventRecord(start[i], stream[i]);
|
||||
cudaCheckError();
|
||||
|
||||
if (i == j) {
|
||||
// Perform intra-GPU, D2D copies
|
||||
performP2PCopy(buffers[i], i, buffersD2D[i], i, numElems, repeat,
|
||||
access, stream[i]);
|
||||
|
||||
} else {
|
||||
if (p2p_method == P2P_WRITE) {
|
||||
performP2PCopy(buffers[j], j, buffers[i], i, numElems, repeat, access,
|
||||
stream[i]);
|
||||
} else {
|
||||
performP2PCopy(buffers[i], i, buffers[j], j, numElems, repeat, access,
|
||||
stream[i]);
|
||||
}
|
||||
}
|
||||
|
||||
cudaEventRecord(stop[i], stream[i]);
|
||||
cudaCheckError();
|
||||
|
||||
// Release the queued events
|
||||
*flag = 1;
|
||||
cudaStreamSynchronize(stream[i]);
|
||||
cudaCheckError();
|
||||
|
||||
float time_ms;
|
||||
cudaEventElapsedTime(&time_ms, start[i], stop[i]);
|
||||
double time_s = time_ms / 1e3;
|
||||
|
||||
double gb = numElems * sizeof(int) * repeat / (double)1e9;
|
||||
if (i == j) {
|
||||
gb *= 2; // must count both the read and the write here
|
||||
}
|
||||
bandwidthMatrix[i * numGPUs + j] = gb / time_s;
|
||||
if (p2p && access) {
|
||||
cudaDeviceDisablePeerAccess(j);
|
||||
cudaSetDevice(j);
|
||||
cudaDeviceDisablePeerAccess(i);
|
||||
cudaSetDevice(i);
|
||||
cudaCheckError();
|
||||
}
|
||||
}
|
||||
}
|
||||
|
||||
printf(" D\\D");
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6d ", j);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
printf("%6d ", i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6.02f ", bandwidthMatrix[i * numGPUs + j]);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
}
|
||||
|
||||
for (int d = 0; d < numGPUs; d++) {
|
||||
cudaSetDevice(d);
|
||||
cudaFree(buffers[d]);
|
||||
cudaFree(buffersD2D[d]);
|
||||
cudaCheckError();
|
||||
cudaEventDestroy(start[d]);
|
||||
cudaCheckError();
|
||||
cudaEventDestroy(stop[d]);
|
||||
cudaCheckError();
|
||||
cudaStreamDestroy(stream[d]);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
cudaFreeHost((void *)flag);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
void outputBidirectionalBandwidthMatrix(int numGPUs, bool p2p) {
|
||||
int numElems = 10000000;
|
||||
int repeat = 5;
|
||||
volatile int *flag = NULL;
|
||||
vector<int *> buffers(numGPUs);
|
||||
vector<int *> buffersD2D(numGPUs);
|
||||
vector<cudaEvent_t> start(numGPUs);
|
||||
vector<cudaEvent_t> stop(numGPUs);
|
||||
vector<cudaStream_t> stream0(numGPUs);
|
||||
vector<cudaStream_t> stream1(numGPUs);
|
||||
|
||||
cudaHostAlloc((void **)&flag, sizeof(*flag), cudaHostAllocPortable);
|
||||
cudaCheckError();
|
||||
|
||||
for (int d = 0; d < numGPUs; d++) {
|
||||
cudaSetDevice(d);
|
||||
cudaMalloc(&buffers[d], numElems * sizeof(int));
|
||||
cudaMalloc(&buffersD2D[d], numElems * sizeof(int));
|
||||
cudaCheckError();
|
||||
cudaEventCreate(&start[d]);
|
||||
cudaCheckError();
|
||||
cudaEventCreate(&stop[d]);
|
||||
cudaCheckError();
|
||||
cudaStreamCreateWithFlags(&stream0[d], cudaStreamNonBlocking);
|
||||
cudaCheckError();
|
||||
cudaStreamCreateWithFlags(&stream1[d], cudaStreamNonBlocking);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
vector<double> bandwidthMatrix(numGPUs * numGPUs);
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
cudaSetDevice(i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
int access = 0;
|
||||
if (p2p) {
|
||||
cudaDeviceCanAccessPeer(&access, i, j);
|
||||
if (access) {
|
||||
cudaSetDevice(i);
|
||||
cudaDeviceEnablePeerAccess(j, 0);
|
||||
cudaCheckError();
|
||||
cudaSetDevice(j);
|
||||
cudaDeviceEnablePeerAccess(i, 0);
|
||||
cudaCheckError();
|
||||
}
|
||||
}
|
||||
|
||||
cudaSetDevice(i);
|
||||
cudaStreamSynchronize(stream0[i]);
|
||||
cudaStreamSynchronize(stream1[j]);
|
||||
cudaCheckError();
|
||||
|
||||
// Block the stream until all the work is queued up
|
||||
// DANGER! - cudaMemcpy*Async may infinitely block waiting for
|
||||
// room to push the operation, so keep the number of repeatitions
|
||||
// relatively low. Higher repeatitions will cause the delay kernel
|
||||
// to timeout and lead to unstable results.
|
||||
*flag = 0;
|
||||
cudaSetDevice(i);
|
||||
// No need to block stream1 since it'll be blocked on stream0's event
|
||||
delay<<<1, 1, 0, stream0[i]>>>(flag);
|
||||
cudaCheckError();
|
||||
|
||||
// Force stream1 not to start until stream0 does, in order to ensure
|
||||
// the events on stream0 fully encompass the time needed for all
|
||||
// operations
|
||||
cudaEventRecord(start[i], stream0[i]);
|
||||
cudaStreamWaitEvent(stream1[j], start[i], 0);
|
||||
|
||||
if (i == j) {
|
||||
// For intra-GPU perform 2 memcopies buffersD2D <-> buffers
|
||||
performP2PCopy(buffers[i], i, buffersD2D[i], i, numElems, repeat,
|
||||
access, stream0[i]);
|
||||
performP2PCopy(buffersD2D[i], i, buffers[i], i, numElems, repeat,
|
||||
access, stream1[i]);
|
||||
} else {
|
||||
if (access && p2p_mechanism == SM) {
|
||||
cudaSetDevice(j);
|
||||
}
|
||||
performP2PCopy(buffers[i], i, buffers[j], j, numElems, repeat, access,
|
||||
stream1[j]);
|
||||
if (access && p2p_mechanism == SM) {
|
||||
cudaSetDevice(i);
|
||||
}
|
||||
performP2PCopy(buffers[j], j, buffers[i], i, numElems, repeat, access,
|
||||
stream0[i]);
|
||||
}
|
||||
|
||||
// Notify stream0 that stream1 is complete and record the time of
|
||||
// the total transaction
|
||||
cudaEventRecord(stop[j], stream1[j]);
|
||||
cudaStreamWaitEvent(stream0[i], stop[j], 0);
|
||||
cudaEventRecord(stop[i], stream0[i]);
|
||||
|
||||
// Release the queued operations
|
||||
*flag = 1;
|
||||
cudaStreamSynchronize(stream0[i]);
|
||||
cudaStreamSynchronize(stream1[j]);
|
||||
cudaCheckError();
|
||||
|
||||
float time_ms;
|
||||
cudaEventElapsedTime(&time_ms, start[i], stop[i]);
|
||||
double time_s = time_ms / 1e3;
|
||||
|
||||
double gb = 2.0 * numElems * sizeof(int) * repeat / (double)1e9;
|
||||
if (i == j) {
|
||||
gb *= 2; // must count both the read and the write here
|
||||
}
|
||||
bandwidthMatrix[i * numGPUs + j] = gb / time_s;
|
||||
if (p2p && access) {
|
||||
cudaSetDevice(i);
|
||||
cudaDeviceDisablePeerAccess(j);
|
||||
cudaSetDevice(j);
|
||||
cudaDeviceDisablePeerAccess(i);
|
||||
}
|
||||
}
|
||||
}
|
||||
|
||||
printf(" D\\D");
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6d ", j);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
printf("%6d ", i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6.02f ", bandwidthMatrix[i * numGPUs + j]);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
}
|
||||
|
||||
for (int d = 0; d < numGPUs; d++) {
|
||||
cudaSetDevice(d);
|
||||
cudaFree(buffers[d]);
|
||||
cudaFree(buffersD2D[d]);
|
||||
cudaCheckError();
|
||||
cudaEventDestroy(start[d]);
|
||||
cudaCheckError();
|
||||
cudaEventDestroy(stop[d]);
|
||||
cudaCheckError();
|
||||
cudaStreamDestroy(stream0[d]);
|
||||
cudaCheckError();
|
||||
cudaStreamDestroy(stream1[d]);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
cudaFreeHost((void *)flag);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
void outputLatencyMatrix(int numGPUs, bool p2p, P2PDataTransfer p2p_method) {
|
||||
int repeat = 100;
|
||||
volatile int *flag = NULL;
|
||||
StopWatchInterface *stopWatch = NULL;
|
||||
vector<int *> buffers(numGPUs);
|
||||
vector<int *> buffersD2D(numGPUs); // buffer for D2D, that is, intra-GPU copy
|
||||
vector<cudaStream_t> stream(numGPUs);
|
||||
vector<cudaEvent_t> start(numGPUs);
|
||||
vector<cudaEvent_t> stop(numGPUs);
|
||||
|
||||
cudaHostAlloc((void **)&flag, sizeof(*flag), cudaHostAllocPortable);
|
||||
cudaCheckError();
|
||||
|
||||
if (!sdkCreateTimer(&stopWatch)) {
|
||||
printf("Failed to create stop watch\n");
|
||||
exit(EXIT_FAILURE);
|
||||
}
|
||||
sdkStartTimer(&stopWatch);
|
||||
|
||||
for (int d = 0; d < numGPUs; d++) {
|
||||
cudaSetDevice(d);
|
||||
cudaStreamCreateWithFlags(&stream[d], cudaStreamNonBlocking);
|
||||
cudaMalloc(&buffers[d], sizeof(int));
|
||||
cudaMalloc(&buffersD2D[d], sizeof(int));
|
||||
cudaCheckError();
|
||||
cudaEventCreate(&start[d]);
|
||||
cudaCheckError();
|
||||
cudaEventCreate(&stop[d]);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
vector<double> gpuLatencyMatrix(numGPUs * numGPUs);
|
||||
vector<double> cpuLatencyMatrix(numGPUs * numGPUs);
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
cudaSetDevice(i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
int access = 0;
|
||||
if (p2p) {
|
||||
cudaDeviceCanAccessPeer(&access, i, j);
|
||||
if (access) {
|
||||
cudaDeviceEnablePeerAccess(j, 0);
|
||||
cudaCheckError();
|
||||
cudaSetDevice(j);
|
||||
cudaDeviceEnablePeerAccess(i, 0);
|
||||
cudaSetDevice(i);
|
||||
cudaCheckError();
|
||||
}
|
||||
}
|
||||
cudaStreamSynchronize(stream[i]);
|
||||
cudaCheckError();
|
||||
|
||||
// Block the stream until all the work is queued up
|
||||
// DANGER! - cudaMemcpy*Async may infinitely block waiting for
|
||||
// room to push the operation, so keep the number of repeatitions
|
||||
// relatively low. Higher repeatitions will cause the delay kernel
|
||||
// to timeout and lead to unstable results.
|
||||
*flag = 0;
|
||||
delay<<<1, 1, 0, stream[i]>>>(flag);
|
||||
cudaCheckError();
|
||||
cudaEventRecord(start[i], stream[i]);
|
||||
|
||||
sdkResetTimer(&stopWatch);
|
||||
if (i == j) {
|
||||
// Perform intra-GPU, D2D copies
|
||||
performP2PCopy(buffers[i], i, buffersD2D[i], i, 1, repeat, access,
|
||||
stream[i]);
|
||||
} else {
|
||||
if (p2p_method == P2P_WRITE) {
|
||||
performP2PCopy(buffers[j], j, buffers[i], i, 1, repeat, access,
|
||||
stream[i]);
|
||||
} else {
|
||||
performP2PCopy(buffers[i], i, buffers[j], j, 1, repeat, access,
|
||||
stream[i]);
|
||||
}
|
||||
}
|
||||
float cpu_time_ms = sdkGetTimerValue(&stopWatch);
|
||||
|
||||
cudaEventRecord(stop[i], stream[i]);
|
||||
// Now that the work has been queued up, release the stream
|
||||
*flag = 1;
|
||||
cudaStreamSynchronize(stream[i]);
|
||||
cudaCheckError();
|
||||
|
||||
float gpu_time_ms;
|
||||
cudaEventElapsedTime(&gpu_time_ms, start[i], stop[i]);
|
||||
|
||||
gpuLatencyMatrix[i * numGPUs + j] = gpu_time_ms * 1e3 / repeat;
|
||||
cpuLatencyMatrix[i * numGPUs + j] = cpu_time_ms * 1e3 / repeat;
|
||||
if (p2p && access) {
|
||||
cudaDeviceDisablePeerAccess(j);
|
||||
cudaSetDevice(j);
|
||||
cudaDeviceDisablePeerAccess(i);
|
||||
cudaSetDevice(i);
|
||||
cudaCheckError();
|
||||
}
|
||||
}
|
||||
}
|
||||
|
||||
printf(" GPU");
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6d ", j);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
printf("%6d ", i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6.02f ", gpuLatencyMatrix[i * numGPUs + j]);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
}
|
||||
|
||||
printf("\n CPU");
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6d ", j);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
printf("%6d ", i);
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6.02f ", cpuLatencyMatrix[i * numGPUs + j]);
|
||||
}
|
||||
|
||||
printf("\n");
|
||||
}
|
||||
|
||||
for (int d = 0; d < numGPUs; d++) {
|
||||
cudaSetDevice(d);
|
||||
cudaFree(buffers[d]);
|
||||
cudaFree(buffersD2D[d]);
|
||||
cudaCheckError();
|
||||
cudaEventDestroy(start[d]);
|
||||
cudaCheckError();
|
||||
cudaEventDestroy(stop[d]);
|
||||
cudaCheckError();
|
||||
cudaStreamDestroy(stream[d]);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
sdkDeleteTimer(&stopWatch);
|
||||
|
||||
cudaFreeHost((void *)flag);
|
||||
cudaCheckError();
|
||||
}
|
||||
|
||||
int main(int argc, char **argv) {
|
||||
int numGPUs;
|
||||
P2PDataTransfer p2p_method = P2P_WRITE;
|
||||
|
||||
cudaGetDeviceCount(&numGPUs);
|
||||
cudaCheckError();
|
||||
|
||||
// process command line args
|
||||
if (checkCmdLineFlag(argc, (const char **)argv, "help")) {
|
||||
printHelp();
|
||||
return 0;
|
||||
}
|
||||
|
||||
if (checkCmdLineFlag(argc, (const char **)argv, "p2p_read")) {
|
||||
p2p_method = P2P_READ;
|
||||
}
|
||||
|
||||
if (checkCmdLineFlag(argc, (const char **)argv, "sm_copy")) {
|
||||
p2p_mechanism = SM;
|
||||
}
|
||||
|
||||
printf("[%s]\n", sSampleName);
|
||||
|
||||
// output devices
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
cudaDeviceProp prop;
|
||||
cudaGetDeviceProperties(&prop, i);
|
||||
cudaCheckError();
|
||||
printf("Device: %d, %s, pciBusID: %x, pciDeviceID: %x, pciDomainID:%x\n", i,
|
||||
prop.name, prop.pciBusID, prop.pciDeviceID, prop.pciDomainID);
|
||||
}
|
||||
|
||||
checkP2Paccess(numGPUs);
|
||||
|
||||
// Check peer-to-peer connectivity
|
||||
printf("P2P Connectivity Matrix\n");
|
||||
printf(" D\\D");
|
||||
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
printf("%6d", j);
|
||||
}
|
||||
printf("\n");
|
||||
|
||||
for (int i = 0; i < numGPUs; i++) {
|
||||
printf("%6d\t", i);
|
||||
for (int j = 0; j < numGPUs; j++) {
|
||||
if (i != j) {
|
||||
int access;
|
||||
cudaDeviceCanAccessPeer(&access, i, j);
|
||||
cudaCheckError();
|
||||
printf("%6d", (access) ? 1 : 0);
|
||||
} else {
|
||||
printf("%6d", 1);
|
||||
}
|
||||
}
|
||||
printf("\n");
|
||||
}
|
||||
|
||||
printf("Unidirectional P2P=Disabled Bandwidth Matrix (GB/s)\n");
|
||||
outputBandwidthMatrix(numGPUs, false, P2P_WRITE);
|
||||
printf("Unidirectional P2P=Enabled Bandwidth (P2P Writes) Matrix (GB/s)\n");
|
||||
outputBandwidthMatrix(numGPUs, true, P2P_WRITE);
|
||||
if (p2p_method == P2P_READ) {
|
||||
printf("Unidirectional P2P=Enabled Bandwidth (P2P Reads) Matrix (GB/s)\n");
|
||||
outputBandwidthMatrix(numGPUs, true, p2p_method);
|
||||
}
|
||||
printf("Bidirectional P2P=Disabled Bandwidth Matrix (GB/s)\n");
|
||||
outputBidirectionalBandwidthMatrix(numGPUs, false);
|
||||
printf("Bidirectional P2P=Enabled Bandwidth Matrix (GB/s)\n");
|
||||
outputBidirectionalBandwidthMatrix(numGPUs, true);
|
||||
|
||||
printf("P2P=Disabled Latency Matrix (us)\n");
|
||||
outputLatencyMatrix(numGPUs, false, P2P_WRITE);
|
||||
printf("P2P=Enabled Latency (P2P Writes) Matrix (us)\n");
|
||||
outputLatencyMatrix(numGPUs, true, P2P_WRITE);
|
||||
if (p2p_method == P2P_READ) {
|
||||
printf("P2P=Enabled Latency (P2P Reads) Matrix (us)\n");
|
||||
outputLatencyMatrix(numGPUs, true, p2p_method);
|
||||
}
|
||||
|
||||
printf(
|
||||
"\nNOTE: The CUDA Samples are not meant for performance measurements. "
|
||||
"Results may vary when GPU Boost is enabled.\n");
|
||||
|
||||
exit(EXIT_SUCCESS);
|
||||
}
|
||||
@@ -0,0 +1,20 @@
|
||||
|
||||
Microsoft Visual Studio Solution File, Format Version 12.00
|
||||
# Visual Studio 2012
|
||||
Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "p2pBandwidthLatencyTest", "p2pBandwidthLatencyTest_vs2012.vcxproj", "{997E0757-EA74-4A4E-A0FC-47D8C8831A15}"
|
||||
EndProject
|
||||
Global
|
||||
GlobalSection(SolutionConfigurationPlatforms) = preSolution
|
||||
Debug|x64 = Debug|x64
|
||||
Release|x64 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(ProjectConfigurationPlatforms) = postSolution
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.ActiveCfg = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.Build.0 = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.ActiveCfg = Release|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.Build.0 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(SolutionProperties) = preSolution
|
||||
HideSolutionNode = FALSE
|
||||
EndGlobalSection
|
||||
EndGlobal
|
||||
@@ -0,0 +1,107 @@
|
||||
<?xml version="1.0" encoding="utf-8"?>
|
||||
<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
|
||||
<PropertyGroup>
|
||||
<CUDAPropsPath Condition="'$(CUDAPropsPath)'==''">$(VCTargetsPath)\BuildCustomizations</CUDAPropsPath>
|
||||
</PropertyGroup>
|
||||
<ItemGroup Label="ProjectConfigurations">
|
||||
<ProjectConfiguration Include="Debug|x64">
|
||||
<Configuration>Debug</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
<ProjectConfiguration Include="Release|x64">
|
||||
<Configuration>Release</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
</ItemGroup>
|
||||
<PropertyGroup Label="Globals">
|
||||
<ProjectGuid>{997E0757-EA74-4A4E-A0FC-47D8C8831A15}</ProjectGuid>
|
||||
<RootNamespace>p2pBandwidthLatencyTest_vs2012</RootNamespace>
|
||||
<ProjectName>p2pBandwidthLatencyTest</ProjectName>
|
||||
<CudaToolkitCustomDir />
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
|
||||
<PropertyGroup>
|
||||
<ConfigurationType>Application</ConfigurationType>
|
||||
<CharacterSet>MultiByte</CharacterSet>
|
||||
<PlatformToolset>v110</PlatformToolset>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<UseDebugLibraries>true</UseDebugLibraries>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Release'">
|
||||
<WholeProgramOptimization>true</WholeProgramOptimization>
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
|
||||
<ImportGroup Label="ExtensionSettings">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.props" />
|
||||
</ImportGroup>
|
||||
<ImportGroup Label="PropertySheets">
|
||||
<Import Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" />
|
||||
</ImportGroup>
|
||||
<PropertyGroup Label="UserMacros" />
|
||||
<PropertyGroup>
|
||||
<IntDir>$(Platform)/$(Configuration)/</IntDir>
|
||||
<IncludePath>$(IncludePath)</IncludePath>
|
||||
<CodeAnalysisRuleSet>AllRules.ruleset</CodeAnalysisRuleSet>
|
||||
<CodeAnalysisRules />
|
||||
<CodeAnalysisRuleAssemblies />
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Platform)'=='x64'">
|
||||
<OutDir>../../bin/win64/$(Configuration)/</OutDir>
|
||||
</PropertyGroup>
|
||||
<ItemDefinitionGroup>
|
||||
<ClCompile>
|
||||
<WarningLevel>Level3</WarningLevel>
|
||||
<PreprocessorDefinitions>WIN32;_MBCS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
|
||||
<AdditionalIncludeDirectories>./;$(CudaToolkitDir)/include;../../Common;</AdditionalIncludeDirectories>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<SubSystem>Console</SubSystem>
|
||||
<AdditionalDependencies>cudart_static.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;shell32.lib;ole32.lib;oleaut32.lib;uuid.lib;odbc32.lib;odbccp32.lib;%(AdditionalDependencies)</AdditionalDependencies>
|
||||
<AdditionalLibraryDirectories>$(CudaToolkitLibDir);</AdditionalLibraryDirectories>
|
||||
<OutputFile>$(OutDir)/p2pBandwidthLatencyTest.exe</OutputFile>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<CodeGeneration>compute_30,sm_30;compute_35,sm_35;compute_37,sm_37;compute_50,sm_50;compute_52,sm_52;compute_60,sm_60;compute_61,sm_61;compute_70,sm_70;compute_75,sm_75;</CodeGeneration>
|
||||
<AdditionalOptions>-Xcompiler "/wd 4819" %(AdditionalOptions)</AdditionalOptions>
|
||||
<Include>./;../../Common</Include>
|
||||
<Defines>WIN32</Defines>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<ClCompile>
|
||||
<Optimization>Disabled</Optimization>
|
||||
<RuntimeLibrary>MultiThreadedDebug</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>true</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>Default</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MTd</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Release'">
|
||||
<ClCompile>
|
||||
<Optimization>MaxSpeed</Optimization>
|
||||
<RuntimeLibrary>MultiThreaded</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>false</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>UseLinkTimeCodeGeneration</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MT</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemGroup>
|
||||
<CudaCompile Include="p2pBandwidthLatencyTest.cu" />
|
||||
|
||||
</ItemGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
|
||||
<ImportGroup Label="ExtensionTargets">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.targets" />
|
||||
</ImportGroup>
|
||||
</Project>
|
||||
@@ -0,0 +1,20 @@
|
||||
|
||||
Microsoft Visual Studio Solution File, Format Version 13.00
|
||||
# Visual Studio 2013
|
||||
Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "p2pBandwidthLatencyTest", "p2pBandwidthLatencyTest_vs2013.vcxproj", "{997E0757-EA74-4A4E-A0FC-47D8C8831A15}"
|
||||
EndProject
|
||||
Global
|
||||
GlobalSection(SolutionConfigurationPlatforms) = preSolution
|
||||
Debug|x64 = Debug|x64
|
||||
Release|x64 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(ProjectConfigurationPlatforms) = postSolution
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.ActiveCfg = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.Build.0 = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.ActiveCfg = Release|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.Build.0 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(SolutionProperties) = preSolution
|
||||
HideSolutionNode = FALSE
|
||||
EndGlobalSection
|
||||
EndGlobal
|
||||
@@ -0,0 +1,107 @@
|
||||
<?xml version="1.0" encoding="utf-8"?>
|
||||
<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
|
||||
<PropertyGroup>
|
||||
<CUDAPropsPath Condition="'$(CUDAPropsPath)'==''">$(VCTargetsPath)\BuildCustomizations</CUDAPropsPath>
|
||||
</PropertyGroup>
|
||||
<ItemGroup Label="ProjectConfigurations">
|
||||
<ProjectConfiguration Include="Debug|x64">
|
||||
<Configuration>Debug</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
<ProjectConfiguration Include="Release|x64">
|
||||
<Configuration>Release</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
</ItemGroup>
|
||||
<PropertyGroup Label="Globals">
|
||||
<ProjectGuid>{997E0757-EA74-4A4E-A0FC-47D8C8831A15}</ProjectGuid>
|
||||
<RootNamespace>p2pBandwidthLatencyTest_vs2013</RootNamespace>
|
||||
<ProjectName>p2pBandwidthLatencyTest</ProjectName>
|
||||
<CudaToolkitCustomDir />
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
|
||||
<PropertyGroup>
|
||||
<ConfigurationType>Application</ConfigurationType>
|
||||
<CharacterSet>MultiByte</CharacterSet>
|
||||
<PlatformToolset>v120</PlatformToolset>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<UseDebugLibraries>true</UseDebugLibraries>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Release'">
|
||||
<WholeProgramOptimization>true</WholeProgramOptimization>
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
|
||||
<ImportGroup Label="ExtensionSettings">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.props" />
|
||||
</ImportGroup>
|
||||
<ImportGroup Label="PropertySheets">
|
||||
<Import Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" />
|
||||
</ImportGroup>
|
||||
<PropertyGroup Label="UserMacros" />
|
||||
<PropertyGroup>
|
||||
<IntDir>$(Platform)/$(Configuration)/</IntDir>
|
||||
<IncludePath>$(IncludePath)</IncludePath>
|
||||
<CodeAnalysisRuleSet>AllRules.ruleset</CodeAnalysisRuleSet>
|
||||
<CodeAnalysisRules />
|
||||
<CodeAnalysisRuleAssemblies />
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Platform)'=='x64'">
|
||||
<OutDir>../../bin/win64/$(Configuration)/</OutDir>
|
||||
</PropertyGroup>
|
||||
<ItemDefinitionGroup>
|
||||
<ClCompile>
|
||||
<WarningLevel>Level3</WarningLevel>
|
||||
<PreprocessorDefinitions>WIN32;_MBCS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
|
||||
<AdditionalIncludeDirectories>./;$(CudaToolkitDir)/include;../../Common;</AdditionalIncludeDirectories>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<SubSystem>Console</SubSystem>
|
||||
<AdditionalDependencies>cudart_static.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;shell32.lib;ole32.lib;oleaut32.lib;uuid.lib;odbc32.lib;odbccp32.lib;%(AdditionalDependencies)</AdditionalDependencies>
|
||||
<AdditionalLibraryDirectories>$(CudaToolkitLibDir);</AdditionalLibraryDirectories>
|
||||
<OutputFile>$(OutDir)/p2pBandwidthLatencyTest.exe</OutputFile>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<CodeGeneration>compute_30,sm_30;compute_35,sm_35;compute_37,sm_37;compute_50,sm_50;compute_52,sm_52;compute_60,sm_60;compute_61,sm_61;compute_70,sm_70;compute_75,sm_75;</CodeGeneration>
|
||||
<AdditionalOptions>-Xcompiler "/wd 4819" %(AdditionalOptions)</AdditionalOptions>
|
||||
<Include>./;../../Common</Include>
|
||||
<Defines>WIN32</Defines>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<ClCompile>
|
||||
<Optimization>Disabled</Optimization>
|
||||
<RuntimeLibrary>MultiThreadedDebug</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>true</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>Default</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MTd</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Release'">
|
||||
<ClCompile>
|
||||
<Optimization>MaxSpeed</Optimization>
|
||||
<RuntimeLibrary>MultiThreaded</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>false</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>UseLinkTimeCodeGeneration</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MT</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemGroup>
|
||||
<CudaCompile Include="p2pBandwidthLatencyTest.cu" />
|
||||
|
||||
</ItemGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
|
||||
<ImportGroup Label="ExtensionTargets">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.targets" />
|
||||
</ImportGroup>
|
||||
</Project>
|
||||
@@ -0,0 +1,20 @@
|
||||
|
||||
Microsoft Visual Studio Solution File, Format Version 14.00
|
||||
# Visual Studio 2015
|
||||
Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "p2pBandwidthLatencyTest", "p2pBandwidthLatencyTest_vs2015.vcxproj", "{997E0757-EA74-4A4E-A0FC-47D8C8831A15}"
|
||||
EndProject
|
||||
Global
|
||||
GlobalSection(SolutionConfigurationPlatforms) = preSolution
|
||||
Debug|x64 = Debug|x64
|
||||
Release|x64 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(ProjectConfigurationPlatforms) = postSolution
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.ActiveCfg = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.Build.0 = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.ActiveCfg = Release|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.Build.0 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(SolutionProperties) = preSolution
|
||||
HideSolutionNode = FALSE
|
||||
EndGlobalSection
|
||||
EndGlobal
|
||||
@@ -0,0 +1,107 @@
|
||||
<?xml version="1.0" encoding="utf-8"?>
|
||||
<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
|
||||
<PropertyGroup>
|
||||
<CUDAPropsPath Condition="'$(CUDAPropsPath)'==''">$(VCTargetsPath)\BuildCustomizations</CUDAPropsPath>
|
||||
</PropertyGroup>
|
||||
<ItemGroup Label="ProjectConfigurations">
|
||||
<ProjectConfiguration Include="Debug|x64">
|
||||
<Configuration>Debug</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
<ProjectConfiguration Include="Release|x64">
|
||||
<Configuration>Release</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
</ItemGroup>
|
||||
<PropertyGroup Label="Globals">
|
||||
<ProjectGuid>{997E0757-EA74-4A4E-A0FC-47D8C8831A15}</ProjectGuid>
|
||||
<RootNamespace>p2pBandwidthLatencyTest_vs2015</RootNamespace>
|
||||
<ProjectName>p2pBandwidthLatencyTest</ProjectName>
|
||||
<CudaToolkitCustomDir />
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
|
||||
<PropertyGroup>
|
||||
<ConfigurationType>Application</ConfigurationType>
|
||||
<CharacterSet>MultiByte</CharacterSet>
|
||||
<PlatformToolset>v140</PlatformToolset>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<UseDebugLibraries>true</UseDebugLibraries>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Release'">
|
||||
<WholeProgramOptimization>true</WholeProgramOptimization>
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
|
||||
<ImportGroup Label="ExtensionSettings">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.props" />
|
||||
</ImportGroup>
|
||||
<ImportGroup Label="PropertySheets">
|
||||
<Import Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" />
|
||||
</ImportGroup>
|
||||
<PropertyGroup Label="UserMacros" />
|
||||
<PropertyGroup>
|
||||
<IntDir>$(Platform)/$(Configuration)/</IntDir>
|
||||
<IncludePath>$(IncludePath)</IncludePath>
|
||||
<CodeAnalysisRuleSet>AllRules.ruleset</CodeAnalysisRuleSet>
|
||||
<CodeAnalysisRules />
|
||||
<CodeAnalysisRuleAssemblies />
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Platform)'=='x64'">
|
||||
<OutDir>../../bin/win64/$(Configuration)/</OutDir>
|
||||
</PropertyGroup>
|
||||
<ItemDefinitionGroup>
|
||||
<ClCompile>
|
||||
<WarningLevel>Level3</WarningLevel>
|
||||
<PreprocessorDefinitions>WIN32;_MBCS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
|
||||
<AdditionalIncludeDirectories>./;$(CudaToolkitDir)/include;../../Common;</AdditionalIncludeDirectories>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<SubSystem>Console</SubSystem>
|
||||
<AdditionalDependencies>cudart_static.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;shell32.lib;ole32.lib;oleaut32.lib;uuid.lib;odbc32.lib;odbccp32.lib;%(AdditionalDependencies)</AdditionalDependencies>
|
||||
<AdditionalLibraryDirectories>$(CudaToolkitLibDir);</AdditionalLibraryDirectories>
|
||||
<OutputFile>$(OutDir)/p2pBandwidthLatencyTest.exe</OutputFile>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<CodeGeneration>compute_30,sm_30;compute_35,sm_35;compute_37,sm_37;compute_50,sm_50;compute_52,sm_52;compute_60,sm_60;compute_61,sm_61;compute_70,sm_70;compute_75,sm_75;</CodeGeneration>
|
||||
<AdditionalOptions>-Xcompiler "/wd 4819" %(AdditionalOptions)</AdditionalOptions>
|
||||
<Include>./;../../Common</Include>
|
||||
<Defines>WIN32</Defines>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<ClCompile>
|
||||
<Optimization>Disabled</Optimization>
|
||||
<RuntimeLibrary>MultiThreadedDebug</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>true</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>Default</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MTd</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Release'">
|
||||
<ClCompile>
|
||||
<Optimization>MaxSpeed</Optimization>
|
||||
<RuntimeLibrary>MultiThreaded</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>false</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>UseLinkTimeCodeGeneration</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MT</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemGroup>
|
||||
<CudaCompile Include="p2pBandwidthLatencyTest.cu" />
|
||||
|
||||
</ItemGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
|
||||
<ImportGroup Label="ExtensionTargets">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.targets" />
|
||||
</ImportGroup>
|
||||
</Project>
|
||||
@@ -0,0 +1,20 @@
|
||||
|
||||
Microsoft Visual Studio Solution File, Format Version 12.00
|
||||
# Visual Studio 2017
|
||||
Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "p2pBandwidthLatencyTest", "p2pBandwidthLatencyTest_vs2017.vcxproj", "{997E0757-EA74-4A4E-A0FC-47D8C8831A15}"
|
||||
EndProject
|
||||
Global
|
||||
GlobalSection(SolutionConfigurationPlatforms) = preSolution
|
||||
Debug|x64 = Debug|x64
|
||||
Release|x64 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(ProjectConfigurationPlatforms) = postSolution
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.ActiveCfg = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Debug|x64.Build.0 = Debug|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.ActiveCfg = Release|x64
|
||||
{997E0757-EA74-4A4E-A0FC-47D8C8831A15}.Release|x64.Build.0 = Release|x64
|
||||
EndGlobalSection
|
||||
GlobalSection(SolutionProperties) = preSolution
|
||||
HideSolutionNode = FALSE
|
||||
EndGlobalSection
|
||||
EndGlobal
|
||||
@@ -0,0 +1,108 @@
|
||||
<?xml version="1.0" encoding="utf-8"?>
|
||||
<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
|
||||
<PropertyGroup>
|
||||
<CUDAPropsPath Condition="'$(CUDAPropsPath)'==''">$(VCTargetsPath)\BuildCustomizations</CUDAPropsPath>
|
||||
</PropertyGroup>
|
||||
<ItemGroup Label="ProjectConfigurations">
|
||||
<ProjectConfiguration Include="Debug|x64">
|
||||
<Configuration>Debug</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
<ProjectConfiguration Include="Release|x64">
|
||||
<Configuration>Release</Configuration>
|
||||
<Platform>x64</Platform>
|
||||
</ProjectConfiguration>
|
||||
</ItemGroup>
|
||||
<PropertyGroup Label="Globals">
|
||||
<ProjectGuid>{997E0757-EA74-4A4E-A0FC-47D8C8831A15}</ProjectGuid>
|
||||
<RootNamespace>p2pBandwidthLatencyTest_vs2017</RootNamespace>
|
||||
<ProjectName>p2pBandwidthLatencyTest</ProjectName>
|
||||
<CudaToolkitCustomDir />
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
|
||||
<PropertyGroup>
|
||||
<ConfigurationType>Application</ConfigurationType>
|
||||
<CharacterSet>MultiByte</CharacterSet>
|
||||
<PlatformToolset>v141</PlatformToolset>
|
||||
<WindowsTargetPlatformVersion>10.0.15063.0</WindowsTargetPlatformVersion>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<UseDebugLibraries>true</UseDebugLibraries>
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Configuration)'=='Release'">
|
||||
<WholeProgramOptimization>true</WholeProgramOptimization>
|
||||
</PropertyGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
|
||||
<ImportGroup Label="ExtensionSettings">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.props" />
|
||||
</ImportGroup>
|
||||
<ImportGroup Label="PropertySheets">
|
||||
<Import Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" />
|
||||
</ImportGroup>
|
||||
<PropertyGroup Label="UserMacros" />
|
||||
<PropertyGroup>
|
||||
<IntDir>$(Platform)/$(Configuration)/</IntDir>
|
||||
<IncludePath>$(IncludePath)</IncludePath>
|
||||
<CodeAnalysisRuleSet>AllRules.ruleset</CodeAnalysisRuleSet>
|
||||
<CodeAnalysisRules />
|
||||
<CodeAnalysisRuleAssemblies />
|
||||
</PropertyGroup>
|
||||
<PropertyGroup Condition="'$(Platform)'=='x64'">
|
||||
<OutDir>../../bin/win64/$(Configuration)/</OutDir>
|
||||
</PropertyGroup>
|
||||
<ItemDefinitionGroup>
|
||||
<ClCompile>
|
||||
<WarningLevel>Level3</WarningLevel>
|
||||
<PreprocessorDefinitions>WIN32;_MBCS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
|
||||
<AdditionalIncludeDirectories>./;$(CudaToolkitDir)/include;../../Common;</AdditionalIncludeDirectories>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<SubSystem>Console</SubSystem>
|
||||
<AdditionalDependencies>cudart_static.lib;kernel32.lib;user32.lib;gdi32.lib;winspool.lib;comdlg32.lib;advapi32.lib;shell32.lib;ole32.lib;oleaut32.lib;uuid.lib;odbc32.lib;odbccp32.lib;%(AdditionalDependencies)</AdditionalDependencies>
|
||||
<AdditionalLibraryDirectories>$(CudaToolkitLibDir);</AdditionalLibraryDirectories>
|
||||
<OutputFile>$(OutDir)/p2pBandwidthLatencyTest.exe</OutputFile>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<CodeGeneration>compute_30,sm_30;compute_35,sm_35;compute_37,sm_37;compute_50,sm_50;compute_52,sm_52;compute_60,sm_60;compute_61,sm_61;compute_70,sm_70;compute_75,sm_75;</CodeGeneration>
|
||||
<AdditionalOptions>-Xcompiler "/wd 4819" %(AdditionalOptions)</AdditionalOptions>
|
||||
<Include>./;../../Common</Include>
|
||||
<Defines>WIN32</Defines>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Debug'">
|
||||
<ClCompile>
|
||||
<Optimization>Disabled</Optimization>
|
||||
<RuntimeLibrary>MultiThreadedDebug</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>true</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>Default</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MTd</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemDefinitionGroup Condition="'$(Configuration)'=='Release'">
|
||||
<ClCompile>
|
||||
<Optimization>MaxSpeed</Optimization>
|
||||
<RuntimeLibrary>MultiThreaded</RuntimeLibrary>
|
||||
</ClCompile>
|
||||
<Link>
|
||||
<GenerateDebugInformation>false</GenerateDebugInformation>
|
||||
<LinkTimeCodeGeneration>UseLinkTimeCodeGeneration</LinkTimeCodeGeneration>
|
||||
</Link>
|
||||
<CudaCompile>
|
||||
<Runtime>MT</Runtime>
|
||||
<TargetMachinePlatform>64</TargetMachinePlatform>
|
||||
</CudaCompile>
|
||||
</ItemDefinitionGroup>
|
||||
<ItemGroup>
|
||||
<CudaCompile Include="p2pBandwidthLatencyTest.cu" />
|
||||
|
||||
</ItemGroup>
|
||||
<Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
|
||||
<ImportGroup Label="ExtensionTargets">
|
||||
<Import Project="$(CUDAPropsPath)\CUDA 10.0.targets" />
|
||||
</ImportGroup>
|
||||
</Project>
|
||||
Reference in New Issue
Block a user